#
# Configuration file for using the XML library in GNOME applications
#
XML2_LIBDIR="-L/root/worker/containers/00002m96tv6/tmp/build/80754af9/libxml2_1603239258104/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/lib"
XML2_LIBS="-lxml2 -L/root/worker/containers/00002m96tv6/tmp/build/80754af9/libxml2_1603239258104/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/lib -lz -L/root/worker/containers/00002m96tv6/tmp/build/80754af9/libxml2_1603239258104/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/lib -llzma -lpthread -L/root/worker/containers/00002m96tv6/tmp/build/80754af9/libxml2_1603239258104/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/lib -L/root/worker/containers/00002m96tv6/tmp/build/80754af9/libxml2_1603239258104/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/lib -licui18n -licuuc -licudata -lm "
XML2_INCLUDEDIR="-I/root/worker/containers/00002m96tv6/tmp/build/80754af9/libxml2_1603239258104/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/include/libxml2 -I/root/worker/containers/00002m96tv6/tmp/build/80754af9/libxml2_1603239258104/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/include"
MODULE_VERSION="xml2-2.9.10"

